#!/usr/bin/env python3

# -*- coding: UTF-8 -*-

"""
Description: Launch the script dedicated to find communities
"""


from .community_finder import multiple_community_launcher
import lazyparser as lp
from .config import ConfigGraph
from typing import List
from .install_hipMCL import install_hipmcl
from .sf_and_communities import multiple_stat_launcher


@lp.parse
def launcher(weight: List[int] = (1),
             global_weight: List[int] = (0),
             same_gene: bool = True,
             ps: int = ConfigGraph.cpu,
             html_fig: bool = False,
             logging_level: str = "DISABLE"):
    """
    Script used to find communities inside  exon co-localized within a project

    :param weight: The weight of interaction to consider (default 1)
    :param global_weight: The global weight to consider. if \
    the global weight is equal to 0 then then density figure are calculated \
    by project, else all project are merge together and the interaction \
    seen in `global_weight` project are taken into account (default 0)
    :param project: The name of the project of interest (default GSM1517081)
    :param same_gene: Say if we consider as co-localised, exons within the \
    same gene (True) or not (False) (default True)
    :param  html_fig: True to display the html figure (default False).
    :param logging_level: The level of data to display (default 'DISABLE')
    """
    if not ConfigGraph.get_hipmcl_prog().is_file():
        install_hipmcl("INFO")
    multiple_community_launcher(1, weight, global_weight, same_gene, html_fig,
                                logging_level)
    multiple_stat_launcher(ps, weight, global_weight, same_gene,
                           logging_level)


launcher()